==> feed_plugin-0.0.50.tar.gz: example/lib/app.dart <==
import 'package:feed_plugin/feed_plugin.dart';
import 'package:flutter/material.dart';
import 'package:feed_plugin_example/localization/localizations.dart';

class App extends StatefulWidget {
  const App({
    Key key,
  }) : super(key: key);

  @override
  _AppState createState() => _AppState();
}

class _AppState extends State<App> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final loc = PhonedoLocalizations.of(context);
    return Directionality(
      textDirection: TextDirection.ltr,
      child: FeedPlugin(
        token:
            "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJpYXQiOjE2MTY0MjE2MzgsImV4cCI6MTYxODkyMTYzOCwicm9sZXMiOlsiUk9MRV9VU0VSIiwiUk9MRV9QQVJUTkVSIl0sImlkIjoiMTdjM2QyYmQtYjhiZC00MTIyLWIwMGMtNjk1MDQ3NTJiZjA2IiwidHlwZSI6IlBhcnRuZXJVc2VyIn0.GKWVm6ZtVA4wW0Erprnhfu78vnYJDIDaZU46cqQMc_ZjHYjqiC3Dle7L_fWiGcLtBfj8EjqcBa_3VpFdoc1wPl0rwUmsFVuu26K2kjVKtfTxkQIB-qJ3RwhJE9r27lctpt8lUnyNMWGo3oMk_mbI57SfWJtUcNb1IkxZ2C7oiSLJyKHVsdekshbdfaf3sH_5Kqg0vE6ou-pUdgRMAZ3LCn-wrGkI-DnU8ESap9WAuBXSXaP2ZUpYOJFPwz3YXUwd3CqedpfRY-q1nx-qncLBDvEGepFFrjOXXk8pIAyQrE3XF6Ti5KKNA4QB8YEfRXFxywp4oHi5rjM-v7v1aQkcIzgC6Aw193KUjwUFvEiKwg9hq8wvgTcZa2dVtd4ZmSgF0XKm_2w6vTz4IyKw19OX5feorkvkV2qjFhFkH1EJmsnfB52CSkO0hP3X5r0wedjdSscjktyqJkf0gc_tWTAlMJ8ZuIUFaSuHKGBBJf3FTM9JhkvkvlTZry6axQbC8UnVbv0I_KTtVO3VIo9_b005s5ivi7AFguVvc2KHyIgGQjFMGTtBBc67Mv3uF8CEuW12SSPymIm8iQzTkkkqTXnzIuAkMdG4bT9pnJu3OUMJ3xV9fC3BhPR08hdPwJf-zlz7FPOynb2m7LhhTyWYhIP-QuHL9kJOlApdEp3xgfWC5og‏",
        firstName: "Moshe",
        lastName: "Levi",
        about: "Telephone secretary at Cellcom",
        profileImg:
            "https://res.cloudinary.com/phonedo/image/upload/v1615195891/botox-for-men_hq0i0j.jpg",
        logo:
            "https://res.cloudinary.com/phonedo/image/upload/v1616506446/%D7%A1%D7%9C%D7%A7%D7%95%D7%9D_bhwz9f.png",
        partnerCompanyName: "Cellcome",
        media: {
          "email": "cellcom@gmail.com",
          "facebook": "https://www.facebook.com/",
          "instagram": "https://www.instagram.com/",
          "linkedin": "https://www.linkedin.com/",
          "phoneNumber": "972-508779672",
          "tiktok": "https://www.tiktok.com/he-IL/",
          "twitter": "https://twitter.com/twitter",
          "website": "https://www.kikar.co.il/",
          "whatsapp": "972-504116642",
          "youtube": "https://www.youtube.com/",
        },
        // partnerToken:
        // "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJpYXQiOjE2MTU3MTQ4NDQsImV4cCI6MTYxODIxNDg0NCwicm9sZXMiOlsiUk9MRV9VU0VSIiwiUk9MRV9QQVJUTkVSIl0sImlkIjoiNzZkNTkzN2UtOTM2OC00Y2FjLWE1NTItZTJiZDVmOTIyZTQzIiwidHlwZSI6IlBhcnRuZXJVc2VyIn0.hmfWnGHKHxzmlO4CkKk8ugWZaQD1huJO0Xvw3W5Agr069HN_hRk3JznsaC0mfcvmRiNF_r07Bhlzub99o14QJf5sikZtzK4jrrGLVVAgUVkamv8C4hlzvFP6tw4HxyVs6efsrXipJJeEdLiSzAQtKxmiuSuzdw2wso2QYY6UJrjiOp5QjzMIvnedZF79JRiNwkSIgnBRscXNpLiEZFjFGpjvvEqsNavNXGp4P9CRurVguOnb1pYn1Q5t2wi12OroWro5yiXOacGd5s5fIluBS7aU9P9YZXZet0eysyHNRamOoP00q4IzeBdek6oL92mhhmkywY862saNRhC3LTFWD9fJBGO1ixvc5FnRM3l3T_KmINSCZYktMXboNwCyaA9_xknGec1ooUeyh-e8Ha6EgJA01-13GshvKVAt_KYTpW9Z76dYVtjr6sRaNY6PyJ84ZJl9673WCBBiwr8e74_aspBbZy76qOHYPeRnlSWStiHMstUAuUNkOMxfea5vcrccfK3Fzrz3HsxBwltox9wLfoEfhuahuW1pifZMkyLcJfjEaN7C5xEl15HFu9YvF2aSjAYPSDRDAaCGY4EeNVDThvigKFKsXbXLU_t5WQQPb3WTvT0AFMgSHCLPHKyEsPRScDpDF2bLrigvHyQHMzcYwqZGSEAAwsFXj7dF8x9v9nM",
        loc: loc,
      ),
    );
  }
}

==> feed_plugin-0.1.11.tar.gz: example/lib/app.dart <==
import 'dart:convert';

import 'package:feed_plugin/feed_plugin.dart';
import 'package:flutter/material.dart';
import 'package:feed_plugin_example/localization/localizations.dart';

class App extends StatefulWidget {
  const App({
    Key key,
  }) : super(key: key);

  @override
  _AppState createState() => _AppState();
}

class _AppState extends State<App> {
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final loc = PhonedoLocalizations.of(context);
    var media = {
      "email": "cellcom@gmail.com",
      "facebook": "https://www.facebook.com/",
      "instagram": "https://www.instagram.com/",
      "linkedin": "https://www.linkedin.com/",
      "phoneNumber": "972-508779672",
      "tiktok": "https://www.tiktok.com/he-IL/",
      "twitter": "https://twitter.com/twitter",
      "website": "https://www.kikar.co.il/",
      "whatsapp": "972-504116642",
      "youtube": "https://www.youtube.com/",
    };
    return Directionality(
      textDirection: TextDirection.ltr,
      child: FeedPlugin(
        token:
            "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJpYXQiOjE2MTY0MjE2MzgsImV4cCI6MTYxODkyMTYzOCwicm9sZXMiOlsiUk9MRV9VU0VSIiwiUk9MRV9QQVJUTkVSIl0sImlkIjoiMTdjM2QyYmQtYjhiZC00MTIyLWIwMGMtNjk1MDQ3NTJiZjA2IiwidHlwZSI6IlBhcnRuZXJVc2VyIn0.GKWVm6ZtVA4wW0Erprnhfu78vnYJDIDaZU46cqQMc_ZjHYjqiC3Dle7L_fWiGcLtBfj8EjqcBa_3VpFdoc1wPl0rwUmsFVuu26K2kjVKtfTxkQIB-qJ3RwhJE9r27lctpt8lUnyNMWGo3oMk_mbI57SfWJtUcNb1IkxZ2C7oiSLJyKHVsdekshbdfaf3sH_5Kqg0vE6ou-pUdgRMAZ3LCn-wrGkI-DnU8ESap9WAuBXSXaP2ZUpYOJFPwz3YXUwd3CqedpfRY-q1nx-qncLBDvEGepFFrjOXXk8pIAyQrE3XF6Ti5KKNA4QB8YEfRXFxywp4oHi5rjM-v7v1aQkcIzgC6Aw193KUjwUFvEiKwg9hq8wvgTcZa2dVtd4ZmSgF0XKm_2w6vTz4IyKw19OX5feorkvkV2qjFhFkH1EJmsnfB52CSkO0hP3X5r0wedjdSscjktyqJkf0gc_tWTAlMJ8ZuIUFaSuHKGBBJf3FTM9JhkvkvlTZry6axQbC8UnVbv0I_KTtVO3VIo9_b005s5ivi7AFguVvc2KHyIgGQjFMGTtBBc67Mv3uF8CEuW12SSPymIm8iQzTkkkqTXnzIuAkMdG4bT9pnJu3OUMJ3xV9fC3BhPR08hdPwJf-zlz7FPOynb2m7LhhTyWYhIP-QuHL9kJOlApdEp3xgfWC5og‏",
        firstName: "Moshe",
        lastName: "Levi",
        about: "Telephone secretary at Cellcom",
        profileImg:
            "https://res.cloudinary.com/phonedo/image/upload/c_scale,q_auto,w_300/v1615195891/botox-for-men_hq0i0j.jpg",
        logo:
            "https://res.cloudinary.com/phonedo/image/upload/v1616506446/%D7%A1%D7%9C%D7%A7%D7%95%D7%9D_bhwz9f.png",
        partnerCompanyName: "Cellcome",
        media: jsonEncode(media),
        // partnerToken:
        // "eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJpYXQiOjE2MTU3MTQ4NDQsImV4cCI6MTYxODIxNDg0NCwicm9sZXMiOlsiUk9MRV9VU0VSIiwiUk9MRV9QQVJUTkVSIl0sImlkIjoiNzZkNTkzN2UtOTM2OC00Y2FjLWE1NTItZTJiZDVmOTIyZTQzIiwidHlwZSI6IlBhcnRuZXJVc2VyIn0.hmfWnGHKHxzmlO4CkKk8ugWZaQD1huJO0Xvw3W5Agr069HN_hRk3JznsaC0mfcvmRiNF_r07Bhlzub99o14QJf5sikZtzK4jrrGLVVAgUVkamv8C4hlzvFP6tw4HxyVs6efsrXipJJeEdLiSzAQtKxmiuSuzdw2wso2QYY6UJrjiOp5QjzMIvnedZF79JRiNwkSIgnBRscXNpLiEZFjFGpjvvEqsNavNXGp4P9CRurVguOnb1pYn1Q5t2wi12OroWro5yiXOacGd5s5fIluBS7aU9P9YZXZet0eysyHNRamOoP00q4IzeBdek6oL92mhhmkywY862saNRhC3LTFWD9fJBGO1ixvc5FnRM3l3T_KmINSCZYktMXboNwCyaA9_xknGec1ooUeyh-e8Ha6EgJA01-13GshvKVAt_KYTpW9Z76dYVtjr6sRaNY6PyJ84ZJl9673WCBBiwr8e74_aspBbZy76qOHYPeRnlSWStiHMstUAuUNkOMxfea5vcrccfK3Fzrz3HsxBwltox9wLfoEfhuahuW1pifZMkyLcJfjEaN7C5xEl15HFu9YvF2aSjAYPSDRDAaCGY4EeNVDThvigKFKsXbXLU_t5WQQPb3WTvT0AFMgSHCLPHKyEsPRScDpDF2bLrigvHyQHMzcYwqZGSEAAwsFXj7dF8x9v9nM",
        loc: loc,
      ),
    );
  }
}
